ApiEndpoints class

API endpoint constants for Better Auth.

Constructors

ApiEndpoints()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

basePath → const String
changePassword → const String
deleteAccount → const String
disableMfa → const String
enableMfa → const String
getSession → const String
listSessions → const String
oauthCallback → const String
oauthSignIn → const String
revokeOtherSessions → const String
revokeSession → const String
signInAnonymous → const String
signInEmail → const String
signInOtp → const String
signInPassword → const String
signOut → const String
signUpEmail → const String
updateAccount → const String
verifyMfa → const String