userNotFound property
Error indicating user not found.
Returned when no account exists for the provided email.
Implementation
static AuthError userNotFound = AuthError(
code: 'USER_NOT_FOUND',
message: 'No account found with this email',
);
Error indicating user not found.
Returned when no account exists for the provided email.
static AuthError userNotFound = AuthError(
code: 'USER_NOT_FOUND',
message: 'No account found with this email',
);