data property
T?
data
final
The data returned from the request.
This is null if the request resulted in an error.
Implementation
final T? data;
The data returned from the request.
This is null if the request resulted in an error.
final T? data;