ClientOptions class

Options for customizing the behavior of the Better Auth client.

Constructors

ClientOptions({bool enableDebugLogging = false, int timeoutSeconds = 30, bool autoRefreshToken = true})
Creates a new ClientOptions instance.
const

Properties

autoRefreshToken bool
Whether to automatically refresh expired tokens.
final
enableDebugLogging bool
Whether to enable debug logging.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeoutSeconds int
Custom timeout for requests in seconds.
final

Methods

copyWith({bool? enableDebugLogging, int? timeoutSeconds, bool? autoRefreshToken}) ClientOptions
Creates a copy with optional overrides.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited