expiresAt property
When the session expires.
After this time, the session is no longer valid and the user will need to re-authenticate.
Implementation
final DateTime expiresAt;
When the session expires.
After this time, the session is no longer valid and the user will need to re-authenticate.
final DateTime expiresAt;