ipAddress property
IP address from which the session was created.
May be null if not provided by the server.
Implementation
final String? ipAddress;
IP address from which the session was created.
May be null if not provided by the server.
final String? ipAddress;