isCurrent property
Whether this session is from the current device.
This flag is true for the session that was used to create it.
Implementation
final bool isCurrent;
Whether this session is from the current device.
This flag is true for the session that was used to create it.
final bool isCurrent;