token property
The session token.
This token is used to authenticate requests and should be stored securely.
Implementation
final String token;
The session token.
This token is used to authenticate requests and should be stored securely.
final String token;