userAgent property
User agent of the device that created the session.
May be null if not provided by the server.
Implementation
final String? userAgent;
User agent of the device that created the session.
May be null if not provided by the server.
final String? userAgent;