SignInModule class

Module for handling sign-in operations.

This module provides methods for authenticating users with various methods including email/password, OTP, and anonymous access.

Obtain an instance from BetterAuthClient.signIn:

final response = await authClient.signIn.email(
  email: 'user@example.com',
  password: 'password123',
);

Constructors

SignInModule(Dio _dio, StorageInterface _storage, BetterAuthClient client)
Creates a new SignInModule instance.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

anonymous({SignInCallbacks? callbacks}) Future<AuthResponse<Session>>
Signs in anonymously (guest user).
email({required String email, required String password, SignInCallbacks? callbacks}) Future<AuthResponse<Session>>
Signs in with email and password authentication.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
otp({required String email, required String otp, SignInCallbacks? callbacks}) Future<AuthResponse<Session>>
Signs in with a one-time password (OTP).
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited