SignUpModule class

Module for handling sign-up operations.

This module provides methods for registering new user accounts.

Obtain an instance from BetterAuthClient.signUp:

final response = await authClient.signUp.email(
  email: 'user@example.com',
  password: 'password123',
  name: 'John Doe',
);

Constructors

SignUpModule(Dio _dio, StorageInterface _storage)
Creates a new SignUpModule instance.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

email({required String email, required String password, String? name, SignUpCallbacks? callbacks}) Future<AuthResponse<User>>
Signs up with email and password.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited