emailVerified property
Whether the email has been verified.
This flag indicates if the user has completed email verification.
Implementation
final bool emailVerified;
Whether the email has been verified.
This flag indicates if the user has completed email verification.
final bool emailVerified;