id property
Unique user identifier.
This ID is generated by the backend and uniquely identifies the user across the entire system.
Implementation
final String id;
Unique user identifier.
This ID is generated by the backend and uniquely identifies the user across the entire system.
final String id;