dispose method
void
dispose()
Disposes of resources used by the client.
Call this method when the client is no longer needed to clean up the Dio client and session notifier.
Implementation
void dispose() {
_dio.close();
_sessionNotifier.dispose();
}