ClientConfig class
Configuration class for the Better Auth client.
Constructors
- ClientConfig({required String baseUrl, ClientOptions options = const ClientOptions()})
- Creates a new ClientConfig instance.
Properties
- baseUrl → String
-
The base URL for API requests
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- options → ClientOptions
-
Additional options for the client
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getEndpointUrl(
String endpoint) → String - Gets the full URL for an API endpoint
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited