SignUpCallbacks class
Callbacks for sign-up request lifecycle.
Use these callbacks to execute code at specific points during the sign-up process.
Example:
authClient.signUp.email(
email: email,
password: password,
callbacks: SignUpCallbacks(
onSuccess: (user) => showWelcome(user),
onError: (error) => showError(error.message),
),
);
Constructors
- SignUpCallbacks({void onRequest()?, void onSuccess(User user)?, void onError(AuthError error)?})
- Creates a new SignUpCallbacks instance.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- onError → void Function(AuthError error)?
-
Called when sign-up fails.
final
- onRequest → void Function()?
-
Called when the sign-up request starts.
final
- onSuccess → void Function(User user)?
-
Called on successful sign-up.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited